<?php

/*

 * Copyright 2011 Google Inc.

 *

 * Licensed under the Apache License, Version 2.0 (the "License");

 * you may not use this file except in compliance with the License.

 * You may obtain a copy of the License at

 *

 *     http://www.apache.org/licenses/LICENSE-2.0

 *

 * Unless required by applicable law or agreed to in writing, software

 * distributed under the License is distributed on an "AS IS" BASIS,

 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.

 * See the License for the specific language governing permissions and

 * limitations under the License.

 */

include_once "templates/base.php";

session_start();



require_once realpath(dirname(__FILE__) . '/../src/Google/autoload.php');



/************************************************

  ATTENTION: Fill in these values! Make sure

  the redirect URI is to this page, e.g:

  http://localhost:8080/user-example.php

 ************************************************/

 $client_id = '649847755306-2dho7k7pge81pn8qdejopbb55hk9v3pk.apps.googleusercontent.com';

 $client_secret = '2pu9oFlKJNBg5xlRdkEh1Bq6';

 $redirect_uri = 'http://helixhouse.info/google-api-php-client/examples/user-example.php';



/************************************************

  Make an API request on behalf of a user. In

  this case we need to have a valid OAuth 2.0

  token for the user, so we need to send them

  through a login flow. To do this we need some

  information from our API console project.

 ************************************************/

$client = new Google_Client();

$client->setClientId($client_id);

$client->setClientSecret($client_secret);

$client->setRedirectUri($redirect_uri);

$client->addScope(Google_Service_Analytics::ANALYTICS_READONLY);



/************************************************

  When we create the service here, we pass the

  client to it. The client then queries the service

  for the required scopes, and uses that when

  generating the authentication URL later.

 ************************************************/

$analytics = new Google_Service_Analytics($client);



/************************************************

  If we're logging out we just need to clear our

  local access token in this case

 ************************************************/

if (isset($_REQUEST['logout'])) {

  unset($_SESSION['access_token']);


}



/************************************************

  If we have a code back from the OAuth 2.0 flow,

  we need to exchange that with the authenticate()

  function. We store the resultant access token

  bundle in the session, and redirect to ourself.

 ************************************************/

if (isset($_GET['code'])) {

  $client->authenticate($_GET['code']);

  $_SESSION['access_token'] = $client->getAccessToken();

  $redirect = 'http://' . $_SERVER['HTTP_HOST'] . $_SERVER['PHP_SELF'];

  header('Location: ' . filter_var($redirect, FILTER_SANITIZE_URL));

}



/************************************************

  If we have an access token, we can make

  requests, else we generate an authentication URL.

 ************************************************/

if (isset($_SESSION['access_token']) && $_SESSION['access_token']) {

  $client->setAccessToken($_SESSION['access_token']);

} else {

  $authUrl = $client->createAuthUrl();

}



/************************************************

  If we're signed in and have a request to shorten

  a URL, then we create a new URL object, set the

  unshortened URL, and call the 'insert' method on

  the 'url' resource. Note that we re-store the

  access_token bundle, just in case anything

  changed during the request - the main thing that

  might happen here is the access token itself is

  refreshed if the application has offline access.

 ************************************************/



?>

<div class="box">

  <div class="request">

<?php 
function getFirstprofileId(&$analytics) {
  // Get the user's first view (profile) ID.

  // Get the list of accounts for the authorized user.
  $accounts = $analytics->management_accounts->listManagementAccounts();

  if (count($accounts->getItems()) > 0) {
    $items = $accounts->getItems();
    $firstAccountId = $items[0]->getId();

    // Get the list of properties for the authorized user.
    $properties = $analytics->management_webproperties
        ->listManagementWebproperties($firstAccountId);

    if (count($properties->getItems()) > 0) {
      $items = $properties->getItems();
      $firstPropertyId = $items[0]->getId();

      // Get the list of views (profiles) for the authorized user.
      $profiles = $analytics->management_profiles
          ->listManagementProfiles($firstAccountId, $firstPropertyId);

      if (count($profiles->getItems()) > 0) {
        $items = $profiles->getItems();

        // Return the first view (profile) ID.
        return $items[0]->getId();

      } else {
        throw new Exception('No views (profiles) found for this user.');
      }
    } else {
      throw new Exception('No properties found for this user.');
    }
  } else {
    throw new Exception('No accounts found for this user.');
  }
}

function getResults(&$analytics, $profileId) {
  // Calls the Core Reporting API and queries for the number of sessions
  // for the last seven days.
  return $analytics->data_ga->get(
      'ga:' . $profileId,
      '7daysAgo',
      'today',
      'ga:sessions');
}

function printResults(&$results) {
  // Parses the response from the Core Reporting API and prints
  // the profile name and total sessions.
  if (count($results->getRows()) > 0) {

    // Get the profile name.
    $profileName = $results->getProfileInfo()->getProfileName();

    // Get the entry for the first entry in the first row.
    $rows = $results->getRows();
    $sessions = $rows[0][0];

    // Print the results.
    print "<p>First view (profile) found: $profileName</p>";
    print "<p>Total sessions: $sessions</p>";
  } else {
    print "<p>No results found.</p>";
  }
}

if (isset($authUrl)) {

  echo "<a class='login' href='" . $authUrl . "'>Connect Me!</a>";

} else {
  $profile = getFirstProfileId($analytics);
$results = getResults($analytics, $profile);
printResults($results);

try {
  $accounts = $analytics->management_accounts->listManagementAccounts();
} catch (apiServiceException $e) {
  print 'There was an Analytics API service error '
      . $e->getCode() . ':' . $e->getMessage();

} catch (apiException $e) {
  print 'There was a general API error '
      . $e->getCode() . ':' . $e->getMessage();
}
foreach ($accounts->getItems() as $account) {
  $html = <<<HTML
<pre>
Account id   = {$account->getId()}
Account name = {$account->getName()}
Created      = {$account->getCreated()}
Updated      = {$account->getUpdated()}
</pre>
HTML;
  print $html;
}

  echo <<<END

    <form id="url" method="GET" action="{$_SERVER['PHP_SELF']}">

      <input name="url" class="url" type="text">

      <input type="submit" value="Shorten">

    </form>

    <a class='logout' href='?logout'>Logout</a>

END;

}

?>

  </div>



  <div class="shortened">

<?php

if (isset($short)) {

  var_dump($short);

}

?>

  </div>

</div>

<?php

echo pageFooter(__FILE__);

